
package Warewulf::Include;

use Exporter;
use File::Basename;
use vars ('$VERSION', '%wwconfig');

our @ISA = ("Exporter");

our @EXPORT = ('&wwconfig');

$VERSION = "3.0";

=head1 NAME

Warewulf::Include - Warewulf base configuration paramaters

=head1 SYNOPSIS

    use Warewulf::Include;

    foreach my $key (keys(%Warewulf::Include::wwconfig)) {
        printf("$key: %s\n", &wwconfig($key));
    }

=head1 DESCRIPTION

This module is auto-generated at build time to contain the configure
options with which Warewulf was built. Including this file will
provide an interface to obtain these configuration values at runtime.
Below is a list of configuration variables supported.

    PROGNAME
    VERSION
    PREFIX
    STATEDIR
    SYSCONFDIR
    LIBDIR
    DATAROOTDIR
    DATADIR
    LIBEXECDIR
    PERLMODDIR

=cut

my $prefix = "/usr";
my $exec_prefix = "/usr";
my $datarootdir = "/usr/share";

$wwconfig{"PROGNAME"}         = basename($0);
$wwconfig{"VERSION"}          = $VERSION;
$wwconfig{"PREFIX"}           = "/usr";
$wwconfig{"STATEDIR"}         = "/var";
$wwconfig{"SYSCONFDIR"}       = "/etc";
$wwconfig{"LIBDIR"}           = "/usr/lib64";
$wwconfig{"DATAROOTDIR"}      = "/usr/share";
$wwconfig{"DATADIR"}          = "/usr/share";
$wwconfig{"LIBEXECDIR"}       = "/usr/libexec";
$wwconfig{"PERLMODDIR"}       = "/usr/lib/perl5/vendor_perl/5.8.8";


sub
wwconfig($)
{
    my $var = uc(shift);

    if (exists($wwconfig{"$var"})) {
        return $wwconfig{"$var"};
    }

    return undef;
}

=head1 SEE ALSO

Warewulf

=head1 COPYRIGHT

Copyright (c) 2001-2003 Gregory M. Kurtzer

Copyright (c) 2003-2011, The Regents of the University of California,
through Lawrence Berkeley National Laboratory (subject to receipt of any
required approvals from the U.S. Dept. of Energy).  All rights reserved.

=cut

1;
